@@ -7,9 +7,6 @@ from discord.http import Route
 from discord.utils import DISCORD_EPOCH
 
 
-# Lmfao look at this pro-gamer move
-Route.BASE = Route.BASE.replace("/v7", "/v8")
-
 
 __all__ = (
     'ResponseType',
